==> qt-creator-2.3.0-src.zip: qt-creator-2.3.0-src/src/plugins/locator/locatorconstants.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef LOCATORCONSTANTS_H
#define LOCATORCONSTANTS_H

#include <QtCore/QtGlobal>

namespace Locator {
namespace Constants {

const char * const FILTER_OPTIONS_PAGE = QT_TRANSLATE_NOOP("Locator", "Filters");
const char * const LOCATOR_CATEGORY = "G.Locator";
const char * const LOCATOR_TR_CATEGORY = QT_TRANSLATE_NOOP("Locator", "Locator");
const char * const SETTINGS_CATEGORY_LOCATOR_ICON = ":/core/images/category_locator.png";
const char * const TASK_INDEX = "Locator.Task.Index";

} // namespace Constants
} // namespace Locator

#endif // LOCATORCONSTANTS_H

==> qt-creator-2.4.1-src.zip: qt-creator-2.4.1-src/src/plugins/locator/locatorconstants.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef LOCATORCONSTANTS_H
#define LOCATORCONSTANTS_H

#include <QtCore/QtGlobal>

namespace Locator {
namespace Constants {

const char * const FILTER_OPTIONS_PAGE = QT_TRANSLATE_NOOP("Locator", "Locator");
const char * const TASK_INDEX = "Locator.Task.Index";

} // namespace Constants
} // namespace Locator

#endif // LOCATORCONSTANTS_H
